@@ -9,6 +9,12 @@ use Carp;
 
 use Moose;
 
+sub _register_status {
+}
+
+sub _collect_job_stats {
+}
+
 with 'HPCI::Run' => { theDriver => 'HPCD::uni' };
 
 has 'stats_keys' => (
@@ -18,12 +24,16 @@ has 'stats_keys' => (
 	default  => sub { [ ] },
 );
 
-sub _collect_job_stats {
-	my $self   = shift;
-	my $status = shift;
+sub _get_submit_command {
+	my $self         = shift;
 
-	my $stath  = $self->stats;
-	$stath->{exit_status} = $status;
-}
+	my $stage        = $self->stage;
+	my $shell_script = $stage->script_file;
+	my $output_file  = $self->_stdout;
+	my $error_file   = $self->_stderr;
+
+	return "exec $shell_script >$output_file 2>$error_file",
+	    $stage->_get_submit_timeouts;
+};
 
 1;
