@@ -16,6 +16,9 @@ use DateTime;
 use MooseX::Role::Parameterized;
 use MooseX::Types::Path::Class qw(Dir File);
 
+## no critic BoutrosLab::HangingComma
+## no critic BoutrosLab::IndentationCheck
+
 parameter theDriver => (
 	isa      => 'Str',
 	required => 1,
@@ -570,6 +573,8 @@ other stage or the attempt is aborted).
 			}
 		}
 		$self->_set_status($ret_stat);
+		$self->systemlogger->($self,$ret_stat)
+		    if $self->can('systemlogger') && $self->_has_systemlogger;
 		return $ret_stat;
 	};
 
